@@ -2,10 +2,10 @@ package Alien::flex;
 
 use strict;
 use warnings;
-use base qw( Alien::Base );
+use base qw( Alien::Base2 );
 
 # ABSTRACT: Find or build flex
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 sub bin_dir
@@ -13,7 +13,7 @@ sub bin_dir
   my($class) = @_;
   if($class->install_type('system'))
   {
-    my $path = $class->config('flex_system_path');
+    my $path = $class->runtime_prop('system_bin_dir');
     return ($path) if $path;
   }
 
@@ -42,7 +42,7 @@ Alien::flex - Find or build flex
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
